# V1alpha1RawArtifact

RawArtifact allows raw string content to be placed as an artifact in a container
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data** | **str** | Data is the string contents of the artifact | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


